@@ -36,7 +36,7 @@ def get_info_json(post_id, auth=None, user_agent=__default_user_agent__):
     
     return r.json()["post"]
 
-def get_info_json_multiple(page=None, page_modifier=None, limit=None, tags=None, auth=None, user_agent=__default_user_agent__):
+def get_info_json_multiple(page=None, page_modifier=None, limit=None, include_deleted=False, tags=None, auth=None, user_agent=__default_user_agent__):
     # Build URL
     url = "{}{}.json".format(__e621_base_url__, __e621_endpoint_posts__)
     
@@ -61,6 +61,9 @@ def get_info_json_multiple(page=None, page_modifier=None, limit=None, tags=None,
     elif page != None:
         raise TypeError("The 'page' parameter must be an integer (use 'page_modifier' for [b]efore and [a]fter)")
     
+    if include_deleted:
+        tags += "+status:any"
+    
     if tags != None:
         if type(tags) != str:
             raise ValueError("The 'tags' parameter must be a string")
@@ -134,6 +137,18 @@ def print_if_true(in_string, do_print):
     if do_print:
         print(in_string)
 def download_image(post_id, output_folder=".", name_pattern=__default_name_pattern__, add_tags=True, save_json=False, use_messages=False, use_warnings=True, custom_json=None, auth=None, user_agent=__default_user_agent__):
+    # Prepare results object
+    results = {
+        "post_exists": True,
+        "post_deleted": False,
+        "post_missing_url": False,
+        "saved_image": False,
+        "saved_tags": False,
+        "saved_json": False,
+        "path_image": "",
+        "path_json": ""
+    }
+    
     # Get information from e621 API
     if custom_json != None:
         image_info = custom_json
@@ -141,17 +156,40 @@ def download_image(post_id, output_folder=".", name_pattern=__default_name_patte
         print_if_true("    Getting info for e621 post...".format(post_id), use_messages)
         image_info = get_info_json(post_id, user_agent=user_agent, auth=auth)
     
-    # Check to make sure it's valid
+    # Check to make sure we got a response
     if image_info == None:
         print_if_true("    ERROR: No info returned.", use_messages)
-        return None
+        results["post_exists"] = False
+        return results
+    
+    # Build file name
+    image_name_base = name_pattern.format(m = image_info["file"]["md5"], i = post_id)
+    image_name = image_name_base + os.path.extsep + image_info["file"]["ext"]
+    image_path = os.path.join(output_folder, image_name)
+    
+    # Save the metadata in a seperate file
+    if save_json:
+        json_path = image_path + os.path.extsep + "json"
+        print_if_true("    Saving metadata JSON...", use_messages)
+        with open(json_path, "w") as f:
+            json.dump(image_info, f, indent=4)
+        results["saved_json"] = True
+        results["path_json"] = json_path
+        print_if_true("    Saved metadata! Location: {}".format(json_path), use_messages)
+        
+    
+    # Check to see if the file was deleted
     if image_info["flags"]["deleted"]:
         print_if_true("    ERROR: Image has been deleted.", use_messages)
-        return None
+        results["post_deleted"] = True
+        return results
     image_url = image_info["file"]["url"]
+    
+    # Check to see if there is no download URL
     if image_url == None:
         print_if_true("    ERROR: Image has no download URL. You may need to use your API key or change your user settings.", use_messages)
-        return None
+        results["post_missing_url"] = True
+        return results
     
     # Create destination folder if it doesn't already exist
     #output_folder = os.path.realpath(output_folder)
@@ -159,16 +197,13 @@ def download_image(post_id, output_folder=".", name_pattern=__default_name_patte
     
     # Download image
     print_if_true("    Downloading image...", use_messages)
-    image_name_base = name_pattern.format(m = image_info["file"]["md5"], i = post_id)
-    image_name = image_name_base + os.path.extsep + image_info["file"]["ext"]
-    
-    image_path = os.path.join(output_folder, image_name)
-    
     urllib.request.urlretrieve(image_url, image_path)
+    results["saved_image"] = True
+    results["path_image"] = image_path
     
     # Try to save metadata directly in the same file
     if add_tags:
-        print_if_true("    Embedding metadata...", use_messages)
+        print_if_true("    Trying to embed metadata...", use_messages)
         try:
             image_tags_obj = imgtag.ImgTag(image_path)
             
@@ -185,20 +220,14 @@ def download_image(post_id, output_folder=".", name_pattern=__default_name_patte
             image_tags = get_tags_from_json(image_info)
             image_tags_obj.add_tags(image_tags)
             image_tags_obj.close()
+            results["saved_tags"] = True
         except SystemError:
             print_if_true("        [FAILED] Could not save metadata in image!", use_messages)
             if use_warnings == True:
                 warnings.warn("Could not save metadata in image!")
     
-    # Save the metadata in a seperate file
-    if save_json:
-        json_path = image_path + os.path.extsep + "json"
-        print_if_true("    Saving metadata JSON...", use_messages)
-        with open(json_path, "w") as f:
-            json.dump(image_info, f, indent=4)
-    
     print_if_true("    Done downloading! Location: {}".format(image_path), use_messages)
-    return image_path
+    return results
 
 
 
@@ -224,7 +253,7 @@ def parse_args(args):
 def main(args):
     args = parse_args(args)
     
-    download_image(post_id=args.post_id, output_folder=args.dl_folder, name_pattern=args.name_pattern, add_tags=args.add_tags, save_json=args.save_json, auth=args.authorization, user_agent=args.user_agent, use_messages=True, use_warnings=False)
+    r = download_image(post_id=args.post_id, output_folder=args.dl_folder, name_pattern=args.name_pattern, add_tags=args.add_tags, save_json=args.save_json, auth=args.authorization, user_agent=args.user_agent, use_messages=True, use_warnings=False)
 
 def run():
     main(sys.argv[1:])
